/*
 * Copyright (C) 2012 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by Pawel Stolowski <pawel.stolowski@canonical.com>
 *
 */

namespace Unity.ShoppingLens
{
  namespace MarkupCleaner
  {
    /**
     * Regex for capturing HTML tags. It's closely related to the logic in replace_cb,
     * so be careful with any changes to it.
     * First three parts of the regex capture <..> tags; there are three variants of it, because
     * we want to capture the actual tag name, without <> and /, so <foo/>, </foo> and <foo> are
     * treated separately in the regex.
     * The last part captures &, unless it's &amp; already.
     */
    internal static const string HTML_MARKUP_RE = "<(.*?)\\s*/>|</\\s*(.*?)>|<(.*?)>|(\\&(?!amp;))";

    internal static bool replace_cb (MatchInfo match, StringBuilder result)
    {
      string? entire_substring = match.fetch (0);
      if (match.get_match_count () > 1 && entire_substring != null)
      {
        if (entire_substring == "&")
        {
          result.append ("&amp;");
        }
        else /* html <..> tags */
        {
          string? html_tag_name = match.fetch (1).down ();
          if (html_tag_name == "br")
          {
            result.append ("\n");
          }
          else if (html_tag_name == "b")
          {
            result.append (entire_substring);
          }
        }
        /* else - ignore all other html tags */
      }
      return false;
    }
    
    public static string html_to_pango_markup (string html_text)
    {
      try
      {
        var html_markup_re = new GLib.Regex (HTML_MARKUP_RE, GLib.RegexCompileFlags.MULTILINE);
        return html_markup_re.replace_eval (html_text, html_text.length, 0, 0, replace_cb);
      }
      catch (GLib.RegexError e) // this shouldn't really happen.. if it happens, it's a programming error
      {
        warning ("Regex compilation failed: %s", e.message);
      }
      return html_text;
    }
  }
}